@@ -4,6 +4,7 @@ import time
 from injector import inject
 
 from .big_data_connector import BigDataConnector
+from .big_data_dialect import BigDataDialect
 from .big_data_policy import BigDataPolicy
 from ......dependency import IScoped
 
@@ -14,6 +15,7 @@ class BigDataContext(IScoped):
                  policy: BigDataPolicy,
                  retry_count=3):
         self.connector: BigDataConnector = policy.connector
+        self.dialect: BigDataDialect = policy.dialect
         self.retry_count = retry_count
         self.default_retry = 1
 
@@ -69,17 +71,17 @@ class BigDataContext(IScoped):
 
     @connect
     def get_table_count(self, query):
-        count_query = self.connector.get_table_count_query(query=query)
+        count_query = self.dialect.get_table_count_query(query=query)
         self.connector.cursor.execute(count_query)
         datas = self.connector.cursor.fetchall()
         return datas[0][0]
 
     def get_table_data(self, query):
-        data_query = self.connector.get_table_data_query(query=query)
+        data_query = self.dialect.get_table_data_query(query=query)
         return self.fetch_query(data_query)
 
     def get_table_data_with_paging(self, query, start, end):
-        data_query = self.connector.get_table_data_with_paging_query(query=query,
+        data_query = self.dialect.get_table_data_with_paging_query(query=query,
                                                                      start=start,
                                                                      end=end)
         results = self.fetch_query(data_query, excluded_columns=['row_number'])
@@ -87,7 +89,7 @@ class BigDataContext(IScoped):
         return results
 
     def truncate_table(self, schema, table):
-        truncate_query = self.connector.get_truncate_query(schema=schema, table=table)
+        truncate_query = self.dialect.get_truncate_query(schema=schema, table=table)
         return self.execute(query=truncate_query)
 
     @staticmethod
@@ -101,7 +103,7 @@ class BigDataContext(IScoped):
         target_query = query
         for column_row in column_rows:
             index = column_rows.index(column_row)
-            indexer = self.connector.get_target_query_indexer().format(index=index)
+            indexer = self.dialect.get_target_query_indexer().format(index=index)
             target_query = self.replace_regex(target_query, column_row[0], indexer)
         return target_query
 
